# eric7.Plugins.WizardPlugins.PyRegExpWizard.PyRegExpWizardCharactersDialog

Module implementing a dialog for entering character classes.

### Global Attributes

None

### Classes

PyRegExpWizardCharactersDialog | Class implementing a dialog for entering character classes.

### Functions

None

## PyRegExpWizardCharactersDialog

Class implementing a dialog for entering character classes.

### Derived from

QDialog, Ui_PyRegExpWizardCharactersDialog

### Class Attributes

predefinedClasses
specialChars

### Class Methods

None

### Methods

PyRegExpWizardCharactersDialog | Constructor
__addRangesLine | Private slot to add a line of entry widgets for character ranges.
__addSinglesLine | Private slot to add a line of entry widgets for single characters.
__formatCharacter | Private method to format the characters entered into the dialog.
__performSelectedAction | Private method performing some actions depending on the input.
__rangesCharTypeSelected | Private slot to handle the activated(int) signal of the char ranges combo boxes.
__singlesCharTypeSelected | Private slot to handle the activated(int) signal of the single chars combo boxes.
getCharacters | Public method to return the character string assembled via the dialog.

### Static Methods

None

#### PyRegExpWizardCharactersDialog (Constructor)

PyRegExpWizardCharactersDialog(parent=None)

Constructor

parent
  parent widget (QWidget)

#### PyRegExpWizardCharactersDialog.__addRangesLine

__addRangesLine()

Private slot to add a line of entry widgets for character ranges.

#### PyRegExpWizardCharactersDialog.__addSinglesLine

__addSinglesLine()

Private slot to add a line of entry widgets for single characters.

#### PyRegExpWizardCharactersDialog.__formatCharacter

__formatCharacter(index, char)

Private method to format the characters entered into the dialog.

index
  selected list index (integer)
char
  character string enetered into the dialog (string)

Return:
  formated character string (string)

#### PyRegExpWizardCharactersDialog.__performSelectedAction

__performSelectedAction(index, lineedit)

Private method performing some actions depending on the input.

index
  selected list index (integer)
lineedit
  line edit widget to act on (QLineEdit)

#### PyRegExpWizardCharactersDialog.__rangesCharTypeSelected

__rangesCharTypeSelected(index, combo)

Private slot to handle the activated(int) signal of the char ranges combo boxes.

index (int)
  selected list index
combo (QComboBox)
  reference to the combo box

#### PyRegExpWizardCharactersDialog.__singlesCharTypeSelected

__singlesCharTypeSelected(index, combo)

Private slot to handle the activated(int) signal of the single chars combo boxes.

index (int)
  selected list index
combo (QComboBox)
  reference to the combo box

#### PyRegExpWizardCharactersDialog.getCharacters

getCharacters()

Public method to return the character string assembled via the dialog.

Return:
  formatted string for character classes (string)

Up